@@ -121,8 +121,9 @@ void CiscoCertificateEnrollment::setupPages()
 	
 	for ( TQStringList::Iterator it = CiscoCaCerts.begin(); it != CiscoCaCerts.end(); ++it )
 	{
-		if ( GlobalConfig->KvpncDebugLevel > 2 )
-			std::cout << "insert item (cisco ca certs):  " << TQString ( *it ) << std::endl;
+		if ( GlobalConfig->KvpncDebugLevel > 2 ) {
+			std::cout << "insert item (cisco ca certs):  " << TQString ( *it ).local8Bit() << std::endl;
+		}
 		selectionpage->CAComboBox->insertItem ( *it );
 	}
 
@@ -739,4 +740,4 @@ void CiscoCertificateEnrollment::readFromStderr_cancel()
 // 	sucess=-1;
 }
 
-
+#include "ciscocertificateenrollment.moc"
